@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "eventfetchjob.h"
@@ -39,6 +25,7 @@ class Q_DECL_HIDDEN EventFetchJob::Private
     QString calendarId;
     QString eventId;
     QString filter;
+    QString syncToken;
     bool fetchDeleted = true;
     quint64 updatedTimestamp = 0;
     quint64 timeMin = 0;
@@ -107,6 +94,16 @@ quint64 EventFetchJob::timeMax() const
     return d->timeMax;
 }
 
+void EventFetchJob::setSyncToken(const QString& syncToken)
+{
+    d->syncToken = syncToken;
+}
+
+QString EventFetchJob::syncToken()
+{
+    return d->syncToken;
+}
+
 void EventFetchJob::setTimeMin(quint64 timestamp)
 {
     if (isRunning()) {
@@ -147,14 +144,18 @@ void EventFetchJob::start()
         if (!d->filter.isEmpty()) {
             query.addQueryItem(QStringLiteral("q"), d->filter);
         }
-        if (d->updatedTimestamp > 0) {
-            query.addQueryItem(QStringLiteral("updatedMin"), Utils::ts2Str(d->updatedTimestamp));
-        }
-        if (d->timeMin > 0) {
-            query.addQueryItem(QStringLiteral("timeMin"), Utils::ts2Str(d->timeMin));
-        }
-        if (d->timeMax > 0) {
-            query.addQueryItem(QStringLiteral("timeMax"), Utils::ts2Str(d->timeMax));
+        if (d->syncToken.isEmpty()) {
+            if (d->updatedTimestamp > 0) {
+                query.addQueryItem(QStringLiteral("updatedMin"), Utils::ts2Str(d->updatedTimestamp));
+            }
+            if (d->timeMin > 0) {
+                query.addQueryItem(QStringLiteral("timeMin"), Utils::ts2Str(d->timeMin));
+            }
+            if (d->timeMax > 0) {
+                query.addQueryItem(QStringLiteral("timeMax"), Utils::ts2Str(d->timeMax));
+            }
+        } else {
+            query.addQueryItem(QStringLiteral("syncToken"), d->syncToken);
         }
         url.setQuery(query);
     } else {
@@ -168,8 +169,9 @@ ObjectsList EventFetchJob::handleReplyWithItems(const QNetworkReply *reply, cons
 {
     if (reply->error() == QNetworkReply::ContentGoneError
         || reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt() == Gone) {
-        // Full sync required by server, redo request with no updatedMin
+        // Full sync required by server, redo request with no updatedMin and no syncToken
         d->updatedTimestamp = 0;
+        d->syncToken.clear();
         start();
         // Errors are not cleared on success
         // Do it here or else the job will fail
@@ -189,6 +191,7 @@ ObjectsList EventFetchJob::handleReplyWithItems(const QNetworkReply *reply, cons
         } else {
             items << CalendarService::JSONToEvent(rawData).dynamicCast<Object>();
         }
+        d->syncToken = feedData.syncToken;
     } else {
         setError(KGAPI2::InvalidResponse);
         setErrorString(tr("Invalid response content type"));
