@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef LIBKGAPI2_EVENTFETCHJOB_H
@@ -114,6 +100,16 @@ class KGAPICALENDAR_EXPORT EventFetchJob : public KGAPI2::FetchJob
      */
     Q_PROPERTY(QString filter READ filter WRITE setFilter)
 
+    /**
+     * @brief A token to fetch updates incrementally
+     *
+     * By default the property is empty. Properties timeMin, timeMax,
+     * updatedMin will be ignored if sync token is specified
+     *
+     * @see setSyncToken, syncToken
+     */
+    Q_PROPERTY(QString syncToken READ syncToken WRITE setSyncToken)
+
   public:
 
     /**
@@ -214,6 +210,18 @@ class KGAPICALENDAR_EXPORT EventFetchJob : public KGAPI2::FetchJob
      */
     quint64 timeMin() const;
 
+    /**
+     * @brief Sets token for incremental updates
+     *
+     * @param syncToken
+     */
+    void setSyncToken(const QString& syncToken);
+
+    /**
+     * @brief Token for next incremental update
+     */
+    QString syncToken();
+
   protected:
 
     /**
