@@ -1,21 +1,7 @@
 /*
- * Copyright 2015  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef KGAPI2_CALENDAR_FREEBUSYQUERYJOB_H
@@ -26,6 +12,7 @@
 
 #include <QVector>
 #include <QDateTime>
+#include <QScopedPointer>
 
 namespace KGAPI2 {
 
@@ -34,7 +21,7 @@ class KGAPICALENDAR_EXPORT FreeBusyQueryJob : public KGAPI2::FetchJob
     Q_OBJECT
 public:
     struct BusyRange {
-        BusyRange() {};
+        BusyRange() = default;
         BusyRange(const QDateTime &busyStart, const QDateTime &busyEnd)
             : busyStart(busyStart), busyEnd(busyEnd)
         {}
@@ -49,12 +36,12 @@ public:
     };
     typedef QVector<BusyRange> BusyRangeList;
 
-    explicit FreeBusyQueryJob(const QString &id, 
+    explicit FreeBusyQueryJob(const QString &id,
                               const QDateTime &timeMin,
                               const QDateTime &timeMax,
                               const AccountPtr &account,
                               QObject* parent = nullptr);
-    ~FreeBusyQueryJob();
+    ~FreeBusyQueryJob() override;
 
     QString id() const;
     QDateTime timeMin() const;
@@ -69,7 +56,7 @@ protected:
 
 private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
