@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "contactcreatejob.h"
@@ -40,6 +26,7 @@ class Q_DECL_HIDDEN ContactCreateJob::Private
   public:
     Private(ContactCreateJob *parent);
     void processNextContact();
+    void setPhoto(const KContacts::Picture &photo, const QString &uid);
 
     QueueHelper<ContactPtr> contacts;
     ContactPtr lastContact;
@@ -83,15 +70,16 @@ void ContactCreateJob::Private::processNextContact()
     }
 
     q->enqueueRequest(request, rawData, QStringLiteral("application/atom+xml"));
+}
 
-    if (!contact->photo().isEmpty()) {
-        const QUrl url = ContactsService::photoUrl(q->account()->accountName(), contact->uid());
-        QNetworkRequest photoRequest(url);
-        photoRequest.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("image/*"));
-        pendingPhoto.first = contact->photo().rawData();
-        pendingPhoto.second = contact->photo().type();
-        q->enqueueRequest(photoRequest, pendingPhoto.first, QStringLiteral("modifyImage"));
-    }
+void ContactCreateJob::Private::setPhoto(const KContacts::Picture &photo, const QString &uid)
+{
+    const QUrl url = ContactsService::photoUrl(q->account()->accountName(), uid);
+    QNetworkRequest photoRequest(url);
+    photoRequest.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("image/*"));
+    pendingPhoto.first = photo.rawData();
+    pendingPhoto.second = photo.type();
+    q->enqueueRequest(photoRequest, pendingPhoto.first, QStringLiteral("modifyImage"));
 }
 
 ContactCreateJob::ContactCreateJob(const ContactsList& contacts, const AccountPtr& account, QObject* parent):
@@ -139,17 +127,23 @@ ObjectsList ContactCreateJob::handleReplyWithItems(const QNetworkReply *reply, c
         if (ct == KGAPI2::JSON) {
             d->lastContact = ContactsService::JSONToContact(rawData);
             items << d->lastContact.dynamicCast<Object>();
-            d->contacts.currentProcessed();
         } else if (ct == KGAPI2::XML) {
             d->lastContact = ContactsService::XMLToContact(rawData);
             items << d->lastContact.dynamicCast<Object>();
-            d->contacts.currentProcessed();
         } else {
             setError(KGAPI2::InvalidResponse);
             setErrorString(tr("Invalid response content type"));
             emitFinished();
             return items;
         }
+        if (!d->contacts.current()->photo().isEmpty()) {
+            // current contact does not have uid populated
+            d->setPhoto(d->contacts.current()->photo(), d->lastContact->uid());
+            d->contacts.currentProcessed();
+        } else {
+            d->contacts.currentProcessed();
+            d->processNextContact();
+        }
     } else {
         if (d->lastContact) {
             KContacts::Picture picture;
@@ -158,11 +152,9 @@ ObjectsList ContactCreateJob::handleReplyWithItems(const QNetworkReply *reply, c
             d->pendingPhoto.first.clear();
             d->pendingPhoto.second.clear();
         }
+        // Enqueue next item or finish
+        d->processNextContact();
     }
-
-    // Enqueue next item or finish
-    d->processNextContact();
-
     return items;
 }
 
