@@ -1,21 +1,7 @@
 /*
-    Copyright (C) 2012 - 2018  Daniel Vrátil <dvratil@kde.org>
+    SPDX-FileCopyrightText: 2012-2018 Daniel Vrátil <dvratil@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "contactsservice.h"
@@ -334,25 +320,25 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     }
 
     /* Formatted name */
-    if (data.contains(QLatin1String("gd$name"))) {
+    if (data.contains(QStringLiteral("gd$name"))) {
         const QVariantMap name = data.value(QStringLiteral("gd$name")).toMap();
 
-        if (name.contains(QLatin1String("gd$fullName"))) {
+        if (name.contains(QStringLiteral("gd$fullName"))) {
             contact->setFormattedName(Private::stringFromXMLMap(name, QStringLiteral("gd$fullName")));
         }
-        if (name.contains(QLatin1String("gd$givenName"))) {
+        if (name.contains(QStringLiteral("gd$givenName"))) {
             contact->setGivenName(Private::stringFromXMLMap(name, QStringLiteral("gd$givenName")));
         }
-        if (name.contains(QLatin1String("gd$familyName"))) {
+        if (name.contains(QStringLiteral("gd$familyName"))) {
             contact->setFamilyName(Private::stringFromXMLMap(name, QStringLiteral("gd$familyName")));
         }
-        if (name.contains(QLatin1String("gd$additionalName"))) {
+        if (name.contains(QStringLiteral("gd$additionalName"))) {
             contact->setAdditionalName(Private::stringFromXMLMap(name, QStringLiteral("gd$additionalName")));
         }
-        if (name.contains(QLatin1String("gd$namePrefix"))) {
+        if (name.contains(QStringLiteral("gd$namePrefix"))) {
             contact->setPrefix(Private::stringFromXMLMap(name, QStringLiteral("gd$namePrefix")));
         }
-        if (name.contains(QLatin1String("gd$nameSuffix"))) {
+        if (name.contains(QStringLiteral("gd$nameSuffix"))) {
             contact->setSuffix(Private::stringFromXMLMap(name, QStringLiteral("gd$nameSuffix")));
         }
     }
@@ -367,32 +353,32 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
         const QVariantList organizations = data.value(QStringLiteral("gd$organization")).toList();
         const QVariantMap organization = organizations.first().toMap();
 
-        if (organization.contains(QLatin1String("gd$orgName"))) {
+        if (organization.contains(QStringLiteral("gd$orgName"))) {
             contact->setOrganization(Private::stringFromXMLMap(organization, QStringLiteral("gd$orgName")));
         }
-        if (organization.contains(QLatin1String("gd$orgDepartment"))) {
+        if (organization.contains(QStringLiteral("gd$orgDepartment"))) {
             contact->setDepartment(Private::stringFromXMLMap(organization, QStringLiteral("gd$orgDepartment")));
         }
-        if (organization.contains(QLatin1String("gd$orgTitle"))) {
+        if (organization.contains(QStringLiteral("gd$orgTitle"))) {
             contact->setTitle(Private::stringFromXMLMap(organization, QStringLiteral("gd$orgTitle")));
         }
-        if (organization.contains(QLatin1String("gd$where"))) {
+        if (organization.contains(QStringLiteral("gd$where"))) {
             contact->setOffice(Private::stringFromXMLMap(organization, QStringLiteral("gd$where")));
         }
     }
 
     /* Nickname */
-    if (data.contains(QLatin1String("gContact$nickname"))) {
+    if (data.contains(QStringLiteral("gContact$nickname"))) {
         contact->setNickName(Private::stringFromXMLMap(data, QStringLiteral("gContact$nickname")));
     }
 
     /* Occupation (= organization/title) */
-    if (data.contains(QLatin1String("gContact$occupation"))) {
+    if (data.contains(QStringLiteral("gContact$occupation"))) {
         contact->setProfession(Private::stringFromXMLMap(data, QStringLiteral("gContact$occupation")));
     }
 
     /* Relationships */
-    if (data.contains(QLatin1String("gContact$relation"))) {
+    if (data.contains(QStringLiteral("gContact$relation"))) {
         const QVariantList relations = data.value(QStringLiteral("gContact$relation")).toList();
         for (const QVariant &r : relations) {
             const QVariantMap relation = r.toMap();
@@ -414,7 +400,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     }
 
     /* Anniversary */
-    if (data.contains(QLatin1String("gContact$event"))) {
+    if (data.contains(QStringLiteral("gContact$event"))) {
         const QVariantList events = data.value(QStringLiteral("gContact$event")).toList();
         for (const QVariant &e : events) {
             const QVariantMap event = e.toMap();
@@ -427,7 +413,7 @@ ObjectPtr Private::JSONToContact(const QVariantMap& data)
     }
 
     /* Websites */
-    if (data.contains(QLatin1String("gContact$website"))) {
+    if (data.contains(QStringLiteral("gContact$website"))) {
         const QVariantList websites = data.value(QStringLiteral("gContact$website")).toList();
         for (const QVariant &w : websites) {
             const QVariantMap web = w.toMap();
