@@ -1,21 +1,7 @@
 /*
-    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
+    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef LIBKGAPI2_DRIVEFILE_H
@@ -475,6 +461,11 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
      */
     QUrl embedLink() const;
 
+    /**
+     * @brief Returns the version of the file;
+     */
+    qlonglong version() const;
+
     /**
      * @brief Returns the time at which this file was shared with the user.
      */
@@ -602,6 +593,60 @@ class KGAPIDRIVE_EXPORT File: public KGAPI2::Object
 
     bool isFolder() const;
 
+    struct Fields {
+        static const QString Items;
+        static const QString SelfLink;
+        static const QString Etag;
+        static const QString Kind;
+        static const QString NextLink;
+        static const QString NextPageToken;
+        static const QString Id;
+        static const QString Title;
+        static const QString MimeType;
+        static const QString Description;
+        static const QString Labels;
+        static const QString CreatedDate;
+        static const QString ModifiedDate;
+        static const QString ModifiedByMeDate;
+        static const QString DownloadUrl;
+        static const QString IndexableText;
+        static const QString UserPermission;
+        static const QString FileExtension;
+        static const QString Md5Checksum;
+        static const QString FileSize;
+        static const QString AlternateLink;
+        static const QString EmbedLink;
+        static const QString SharedWithMeDate;
+        static const QString Parents;
+        static const QString ExportLinks;
+        static const QString OriginalFilename;
+        static const QString OwnerNames;
+        static const QString LastModifiedByMeDate;
+        static const QString Editable;
+        static const QString WritersCanShare;
+        static const QString ThumbnailLink;
+        static const QString LastViewedByMeDate;
+        static const QString WebContentLink;
+        static const QString ExplicitlyTrashed;
+        static const QString ImageMediaMetadata;
+        static const QString Thumbnail;
+        static const QString WebViewLink;
+        static const QString IconLink;
+        static const QString Shared;
+        static const QString Owners;
+        static const QString LastModifyingUser;
+        static const QString AppDataContents;
+        static const QString OpenWithLinks;
+        static const QString DefaultOpenWithLink;
+        static const QString HeadRevisionId;
+        static const QString Copyable;
+        static const QString Properties;
+        static const QString MarkedViewedByMeDate;
+        static const QString Version;
+        static const QString SharingUser;
+        static const QString Permissions;
+    };
+
     static FilePtr fromJSON(const QByteArray &jsonData);
     static FilesList fromJSONFeed(const  QByteArray &jsonData, FeedData &feedData);
     static QByteArray toJSON(const FilePtr &file, SerializationOptions options = NoOptions);
