@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef KGAPI2_DRIVEFILEABSTRACTDATAJOB_H
@@ -98,6 +84,17 @@ class KGAPIDRIVE_EXPORT FileAbstractDataJob : public KGAPI2::Job
                READ timedTextTrackName
                WRITE setTimedTextTrackName)
 
+    /**
+     *  Sets whether the request supports both My Drives and shared drives.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * This property can be modified only when the job is not running.
+     */
+    Q_PROPERTY(bool supportsAllDrives
+               READ supportsAllDrives
+               WRITE setSupportsAllDrives)
+
   public:
     explicit FileAbstractDataJob(const AccountPtr &account,
                                  QObject *parent = nullptr);
@@ -121,6 +118,26 @@ class KGAPIDRIVE_EXPORT FileAbstractDataJob : public KGAPI2::Job
     QString timedTextTrackName() const;
     void setTimedTextTrackName(const QString &timedTextTrackName);
 
+    /**
+     * @brief Whether the request supports both My Drives and shared drives.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
+     * are assumed to support shared drives.
+     */
+    KGAPIDRIVE_DEPRECATED bool supportsAllDrives() const;
+
+    /**
+     * @brief Sets whether the request supports both My Drives and shared drives.
+     *
+     * Set to true by default as LibKGAPI supports Team Drives.
+     *
+     * @deprecated This parameter will only be effective until June 1, 2020. Afterwards all applications
+     * are assumed to support shared drives.
+     */
+    KGAPIDRIVE_DEPRECATED void setSupportsAllDrives(bool supportsAllDrives);
+
   protected:
     QUrl updateUrl(QUrl &url);
 
