@@ -6,7 +6,8 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#pragma once
+#ifndef KGAPI2_DRIVEPERMISSIONFETCHJOB_H
+#define KGAPI2_DRIVEPERMISSIONFETCHJOB_H
 
 #include "fetchjob.h"
 #include "kgapidrive_export.h"
@@ -19,13 +20,18 @@ namespace Drive
 
 class KGAPIDRIVE_EXPORT PermissionFetchJob : public KGAPI2::FetchJob
 {
+
     Q_OBJECT
 
-public:
-    explicit PermissionFetchJob(const QString &fileId, const AccountPtr &account, QObject *parent = nullptr);
-    explicit PermissionFetchJob(const FilePtr &file, const AccountPtr &account, QObject *parent = nullptr);
-    explicit PermissionFetchJob(const QString &fileId, const QString &permissionId, const AccountPtr &account, QObject *parent = nullptr);
-    explicit PermissionFetchJob(const FilePtr &file, const QString &permissionId, const AccountPtr &account, QObject *parent = nullptr);
+  public:
+    explicit PermissionFetchJob(const QString &fileId, const AccountPtr &account,
+                                QObject *parent = nullptr);
+    explicit PermissionFetchJob(const FilePtr &file, const AccountPtr &account,
+                                QObject *parent = nullptr);
+    explicit PermissionFetchJob(const QString &fileId, const QString &permissionId,
+                                const AccountPtr &account, QObject *parent = nullptr);
+    explicit PermissionFetchJob(const FilePtr &file, const QString &permissionId,
+                                const AccountPtr &account, QObject *parent = nullptr);
     ~PermissionFetchJob() override;
 
     /**
@@ -64,11 +70,12 @@ public:
      */
     void setUseDomainAdminAccess(bool useDomainAdminAccess);
 
-protected:
+  protected:
     void start() override;
-    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
+    KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
+            const QByteArray &rawData) override;
 
-private:
+  private:
     class Private;
     QScopedPointer<Private> d;
     friend class Private;
@@ -77,3 +84,5 @@ private:
 } // namespace Drive
 
 } // namespace KGAPI2
+
+#endif // KGAPI2_DRIVEPERMISSIONFETCHJOB_H
