@@ -1,23 +1,9 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef LIBKGAPI2_TASKFETCHJOB_H
@@ -26,6 +12,8 @@
 #include "fetchjob.h"
 #include "kgapitasks_export.h"
 
+#include <QScopedPointer>
+
 namespace KGAPI2 {
 
 /**
@@ -85,7 +73,7 @@ class KGAPITASKS_EXPORT TaskFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Timestamp of the newest completed task that will be fetched
      *
-     * Only tasks that have been completed before or precisely at the time 
+     * Only tasks that have been completed before or precisely at the time
      * indicated by this property will be fetched.
      *
      * By default the timestamp is 0 and no limit is applied.
@@ -100,7 +88,7 @@ class KGAPITASKS_EXPORT TaskFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Timestamp of the oldest completed task that will be fetched
      *
-     * Only tasks that have been completed after or precisely at the time 
+     * Only tasks that have been completed after or precisely at the time
      * indicated by this property will be fetched.
      *
      * By default the timestamp is 0 and no limit is applied.
@@ -130,7 +118,7 @@ class KGAPITASKS_EXPORT TaskFetchJob : public KGAPI2::FetchJob
     /**
      * @brief Timestamp of the oldest due task that will be fetched
      *
-     * Only tasks that are due after or precisely at the time indicated by 
+     * Only tasks that are due after or precisely at the time indicated by
      * this property will be fetched.
      *
      * By default the timestamp is 0 and no limit is applied.
@@ -284,7 +272,7 @@ class KGAPITASKS_EXPORT TaskFetchJob : public KGAPI2::FetchJob
 
   private:
     class Private;
-    Private * const d;
+    QScopedPointer<Private> const d;
     friend class Private;
 
 };
